@@ -21,6 +21,9 @@
 
 #include "kaccountsuiplugin.h"
 
+#include <QWindow>
+#include <QVariant>
+
 KAccountsUiPlugin::KAccountsUiPlugin(QObject *parent)
      : QObject(parent)
 {
@@ -30,4 +33,9 @@ KAccountsUiPlugin::~KAccountsUiPlugin()
 {
 }
 
+QWindow* KAccountsUiPlugin::transientParent() const
+{
+    return property("transientParent").value<QWindow*>();
+}
+
 #include "moc_kaccountsuiplugin.cpp"
